@@ -2,7 +2,7 @@ package Catmandu::Store::ElasticSearch::CQL;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Catmandu::Util qw(require_package trim);
 use CQL::Parser;
@@ -303,6 +303,8 @@ sub _text_node {
     if ($term =~ /[^\\][\*\?]/) { # TODO only works for single terms, mapping
         return { query_string => { query => "$qualifier:$term" } };
     }
+    # Unescape wildcards (when needed)...
+    $term =~ s{[\\]([\^\*\?])}{$1}g;
     for my $m (@modifiers) {
         if ($m->[1] eq 'fuzzy') { # TODO only works for single terms, mapping fuzzy_factor
             return { fuzzy => { $qualifier => { value => $term, max_expansions => 10 } } };
@@ -315,4 +317,3 @@ sub _text_node {
 }
 
 1;
-
